/* format header */

#ifndef HEADER_FORMAT_H
#define HEADER_FORMAT_H

#define SKEW_VAL_DEF 2
#define SKEW_OFS_DEF 1

// flags for all models are kept here for the time being
#define FLAGS_HSOFT  (1 << 0)
#define FLAGS_C5H0S0 (1 << 1)
#define FLAGS_GAMMA  (1 << 2)
#define FLAGS_APPLIX (1 << 3)
#define FLAGS_60     (1 << 4)

enum
{
 det_off,
 det_mbee,
 det_mbee3,
 det_mbee5,
 det_applix,
 det_fm,
};

typedef struct disk_format_t
{
 char name[100]; // format name
 char desc[100]; // format description
 int sidedness;  // how to handle multisided discs
 int cylinders;  // number of cylinders
 int heads;      // number of heads
 int sectors;    // sectors per track
 int secbase;    // first physical sector number
 int secsize;    // sector size in bytes
 int datarate;   // data rate, this is DD in DD drives
 int rwgap;      // read/write gap length
 int fmtgap;     // format gap length
 int fm;         // FM mode
 int nomulti;    // no multitrack
 int noskip;     // no skipping deleted data
 int side1as0;   // side1as0 issue
 int secbase2_c; // 2nd sector base cylinder change
 int secbase2_s; // 2nd sector base first sector
 int skew_val;   // sector skew value
 int skew_ofs;   // offset to apply to sector base
 int special;    // special flags
}disk_format_t;

dsk_err_t read_sector_ids (int cyl, int head, int secsize, int *sizeok,
                           int *size, dsk_psect_t *count,
                           int *txhx_sec_f, int *txhx_sec_l);
dsk_err_t read_physical_sector (dsk_pcyl_t cyl, dsk_pcyl_t xcyl,
                                dsk_phead_t head, dsk_phead_t xhead,
                                int psect, char *buffer);
void format_set_geometry (disk_format_t *disk_format);
void format_list_formats (void);
void format_list_types (void);
int format_detect_disk (void);
int format_set (char *optarg);
int format_detect_select (char *optarg);

#endif     /* HEADER_FORMAT_H */
