/* ubeedisk header */

#ifndef HEADER_UBEEDISK_H
#define HEADER_UBEEDISK_H

#include <libdsk.h>

void close_files (void);
dsk_err_t override_values (void);
int file_disk_description (char *s);
void process_disk_description (char *s);
int scan_option (char *parms);
void reset_input_drive_and_settings (void);

#ifdef WIN32
#define SLASHCHAR '\\'
#define SLASHCHAR_STR "\\"
#define SLASHCHAR_OTHER '/'
#define DIR_CONF "\\"
#else
#define SLASHCHAR '/'
#define SLASHCHAR_STR "/"
#define SLASHCHAR_OTHER '\\'
#define DIR_CONF "/"
#endif

#ifndef WIN32
#undef printf
#define printf(...)  printfx(__VA_ARGS__)
#define fgets fgetsx
#endif

#define SSIZE1 512
#define INFO_SIZE 100000

#define DESC_LINES 100
#define DESC_CHARS 100

#define ESC 27

enum
{
 UBEEDISK_COPY,
 UBEEDISK_DUMP,
 UBEEDISK_GEOMETRY,
 UBEEDISK_SCAN,
 UBEEDISK_FORMAT,
 UBEEDISK_SPEED,
 UBEEDISK_CLEAN
};

typedef struct disk_t
{
 int append_error;
 int autorate;
 int buffering;
 int count;
 int detect;
 int disk;
 int enter_desc;
 int error;
 int finish;
 int first_read;
 int force;
 int forceside;
 int head_s;
 int head_f;
 int idrive_type;
 int ignore_errors;
 int info_file;
 int iside;
 int idstep;
 int idstep_used;
 int log;
 int noformat;
 int odrive_type;
 int odstep;
 int odstep_used;
 int oside;
 int retries_l1;
 int retries_l2;
 int start;
 int support_xread;
 int support_xwrite;
 int verbose;
 int unattended;
 int unattended_retry_abort_max;
 int unattended_retry_sector_max;
 int unattended_seeked_max;
 char format[1000];
 char ifile[1000];
 char incomp[1000];
 char itype[1000];
 char ofile[1000];
 char otype[1000];
 char outcomp[1000];
 char signature[1000];
}disk_t;

typedef struct dg_opts_t
{
 int sidedness;
 int cylinders;
 int heads;
 int sectors;
 int secbase;
 int secsize;
 int datarate;
 int rwgap;    
 int fmtgap;
 int fm;
 int nomulti;
 int noskip;
 int side1as0;
 int secbase1s;
 int secbase2s;
 int secbase2c;
 int skew_val;
 int skew_ofs;
 int special;
 char format_name[1000];
 char format_desc[1000];
}dg_opts_t;

typedef struct xdg_t
{
 int dg_side1as0;
 int dg_secbase1s;
 int dg_secbase2s;
 int dg_secbase2c;
 int dg_idatarate;
 int dg_odatarate;
 int dg_skew_val;
 int dg_skew_ofs;
 int dg_special;
 char dg_format_name[1000];
 char dg_format_desc[1000];
}xdg_t;

typedef struct ext_type_t
{
 char *ext;
 char *type;
}ext_type_t;

typedef struct info_t
{
 int cyl_last;
 int head_last;
 int pos_trk;
 int pos_sec;
 int buf[INFO_SIZE];
}info_t;

typedef struct sup_t
{
 int psecid;
 int ptrackids;
 int pformat;
 int xread;
 int xwrite;
 char remote_interface[101];
 char version[101];
}sup_t;

#endif     /* HEADER_UBEEDISK_H */
